@@ -32,7 +32,11 @@ class SimpleValueModel(object):
 class SimpleValueDictListMode(object):
     @classmethod
     def from_response_data(cls, data, api):
-        return {key:[int(x) for x in val] for key, val in data}
+        resp = dict()
+        for key, val in data.iteritems():
+            resp[key] = [int(x) for x in val]
+
+        return resp
 
 
 class APIModel(dict):
@@ -73,7 +77,6 @@ class APIModel(dict):
             else:
                 self[k] = v
 
-
         annotations = self.get('annotations')
         if annotations:
             self.annotations_by_key = collections.defaultdict(list)
@@ -89,7 +92,6 @@ class APIModel(dict):
         """
         return cls(json.loads(raw_json), api)
 
-
     @classmethod
     def from_response_data(cls, data, api=None):
         """
@@ -100,7 +102,6 @@ class APIModel(dict):
         model = cls(data, api)
         return model
 
-
     def serialize(self):
         """
         Converts :class:`adnpy.models.Model` into a normal dict without references to the api
@@ -109,14 +110,14 @@ class APIModel(dict):
         data = {}
         for k, v in self.iteritems():
             if k.startswith('_'):
-              continue
+                continue
 
             if isinstance(v, APIModel):
-              data[k] = v.serialize()
+                data[k] = v.serialize()
             elif v and is_seq_not_string(v) and isinstance(v[0], APIModel):
-              data[k] = [x.serialize() for x in v]
+                data[k] = [x.serialize() for x in v]
             else:
-              data[k] = v
+                data[k] = v
 
         return data
 
@@ -140,6 +141,11 @@ class APIModel(dict):
         return self.serialize()
 
 
+class APIMeta(APIModel):
+    """API response metadata."""
+    pass
+
+
 class User(APIModel):
     """
     The User Model
@@ -237,7 +243,6 @@ class Post(APIModel):
         """
         return self._api.repost_post(self)
 
-
     def unrepost(self):
         """
         Remove repost of this post
@@ -250,7 +255,6 @@ class Post(APIModel):
         """
         return self._api.star_post(self)
 
-
     def unstar(self):
         """
         Remove star of this post
@@ -327,7 +331,7 @@ class File(APIModel):
     def from_response_data(cls, data, api=None):
         file_ = super(File, cls).from_response_data(data, api)
         if file_.get('user'):
-            file_.user = User.from_response_data(file_.user)
+            file_.user = User.from_response_data(file_.user, api)
 
         return file_
 
@@ -340,7 +344,7 @@ class Token(APIModel):
     def from_response_data(cls, data, api=None):
         token = super(Token, cls).from_response_data(data, api)
         if token.get('user'):
-            token.user = User.from_response_data(token.user)
+            token.user = User.from_response_data(token.user, api)
 
         return token
 
